@@ -248,7 +248,7 @@ class SegfaultDialog(wx.Dialog):
         self.ohDear.SetFont( font )
         
 
-        self.sadStory = wx.StaticText( self, -1, _("There's some problem with the font named below.\nPlease *move* it away somewhere else, or this will keep happening. Start Fonty Python again when you are done.\n" ))
+        self.sadStory = wx.StaticText( self, -1, _("There's some problem with the font named below. Please use the Check Fonts tool in Fonty\n(from the command-line or the File menu) to go through this directory and mark all the dangerous fonts.\n(You could simply move this font elsewhere, but others may remain to cause trouble.)\n" ))
 
         font = wx.Font(11, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
         self.culprit = wx.StaticText( self, -1, culprit ) 
@@ -285,16 +285,18 @@ class DialogCheckFonts( wx.Dialog ):
         wx.Dialog.__init__(self, parent, -1, _("Check for dangerous fonts."), \
         size=(800,400),pos = wx.DefaultPosition, style=wx.DEFAULT_FRAME_STYLE )
         
+        ## LEFT
+        leftsz = wx.BoxSizer(wx.VERTICAL)
         title = wx.StaticText( self,-1,  _("Choose a directory and double click it to start"))
+        leftsz.Add(title,0,wx.EXPAND | wx.ALL, border=4 )
+        self.treedir = wx.GenericDirCtrl( self, -1, dir=startdir, style=wx.DIRCTRL_DIR_ONLY )
+        leftsz.Add( self.treedir, 1, wx.EXPAND|wx.ALL)
+
+        ## RIGHT
+        rightsz = wx.BoxSizer(wx.VERTICAL)
         self.output = wx.TextCtrl( self, -1, "...", \
         size=(200,-1), style = wx.TE_MULTILINE | wx.TE_READONLY )
-        self.treedir = wx.GenericDirCtrl( self, -1, dir=startdir, style=wx.DIRCTRL_DIR_ONLY )
-        self.treedir.SetMinSize((200,200))
-        self.output.SetMinSize((200,200))
-        
-        sy = wx.BoxSizer(wx.VERTICAL)
-        sy.Add(title,0,wx.EXPAND|wx.ALL,border = 4)
-        sy.Add(self.output,1,wx.EXPAND | wx.ALL)
+        rightsz.Add(self.output,1,wx.EXPAND | wx.ALL)
 
         btnsizer = wx.StdDialogButtonSizer()
         btn = wx.Button(self, wx.ID_OK)
@@ -302,12 +304,12 @@ class DialogCheckFonts( wx.Dialog ):
         btnsizer.AddButton(btn)
         btnsizer.Realize()
         
-        sy.Add(btn,0,wx.EXPAND)
+        rightsz.Add(btn,0,wx.EXPAND)
         
         sz = wx.BoxSizer(wx.HORIZONTAL)
         
-        sz.Add(self.treedir,1,wx.EXPAND)
-        sz.Add(sy,1, wx.EXPAND )# this wx.EXPAND got the text control to fit the height.
+        sz.Add(leftsz, 1, wx.EXPAND)
+        sz.Add(rightsz, 1, wx.EXPAND )# this wx.EXPAND got the text control to fit the height.
 
         self.SetSizer(sz)
 
@@ -318,12 +320,14 @@ class DialogCheckFonts( wx.Dialog ):
     def printer( self, txt=None ):
         if txt is None: txt = "\n"
         self.output.WriteText(txt + "\n")
-
+        wx.SafeYield()
+        
     def __goFigure( self, e ):
         self.output.Clear()
+        wx.BeginBusyCursor()
         dirtocheck = self.treedir.GetPath()
         fpsys.checkFonts( dirtocheck, self.printer )
-        
+        wx.EndBusyCursor()
         
         
         
