@@ -171,7 +171,8 @@ class FontItem( object ):
                 
         self.numFaces = i
                 
-    def generatePilFont( self, width, maxHeight, enc="unicode" ):
+    #def generatePilFont( self, width, maxHeight, enc="unicode" ):
+    def generatePilFont( self, maxHeight, enc="unicode" ):
         """
         This function seems too similar to the __queryFontFamilyStyleFlagBad one
         and in many ways it is. I am forced to work with PIL and it's not ideal
@@ -192,6 +193,11 @@ class FontItem( object ):
             try:
                 font = ImageFont.truetype(paf, points,index=i, encoding=enc) 
                 w,h = font.getsize( text )
+                ## Some fonts (50SDINGS.ttf) return a 0 width.
+                ## I don't know exactly why, it could be it could not render
+                ## any of the chars in text.
+                if int(w) == 0: 
+                    w = 1
                 pilheight = int(h)
                 pilwidth = int(w)
                 pilheight = min( pilheight, maxHeight )
