@@ -14,7 +14,7 @@
 ##
 ##    You should have received a copy of the GNU General Public License
 ##    along with Fonty Python.  If not, see <http://www.gnu.org/licenses/>.
-
+import locale
 
 ## The %s must be OUTSIDE the _() construct.
 class Errors ( Exception ):
@@ -35,10 +35,21 @@ class Errors ( Exception ):
     1030 : _("This folder has no fonts in it.")
     }
 
-    ## Dec 2007: This used to be __str__
+#TO DO
+    ## Jan 14 2008 
+    ## I'm a bit fuzzy on these. I use print unicode(e) mostly
+    ## but a few print repr( e )'s have snuck in here and there.
     def __unicode__( self ):
         return u"%s : %s" % ( self.__class__.messages[self._id], self._item )
-
+        
+    def __str__( self ):
+        return "%s : %s" % ( self.__class__.messages[self._id], self._item )
+        
+    def __repr__(self):
+        s = "%s : %s" % ( self.__class__.messages[self._id], self._item )
+        s = s.decode( locale.getpreferredencoding(), errors="replace" )
+        return s
+        
 ## testing i18n with fontybugs
 ##try:
 ##    raise fontybugs.BadVoodoo("bad voodoo")
@@ -115,12 +126,6 @@ class FolderHasNoFonts ( Errors ):
     def __init__ ( self, item = None): 
         self._item = item
         self._id = 1030            
-        
-        
-        
-        
-        
-        
-        
+
         
         
