@@ -1,3 +1,4 @@
+# This Python file uses the following encoding: utf-8
 ##    Fonty Python Copyright (C) 2006, 2007, 2008 Donn.C.Ingle
 ##    Contact: donn.ingle@gmail.com - I hope this email lasts.
 ##
@@ -34,21 +35,44 @@ more details."""
 aboutText = "%s\n%s\nWritten on Gnu\Linux, using wxPython.\n\n%s" % (copyright, version, warranty)
 
 options=_("""Options:
-  -v            Show program's version number and exit.
-  -h            Show this help message and exit.
-  -e            Show some %$@#$ examples!
-  -i pog        Install the fonts in this pog to your 
+  -v --version  Show program's version number and exit.
+  -h --help     Show this help message and exit.
+  -e --examples
+                Show some %$@#$ examples!
+  -i pog --install=pog
+                Install the fonts in this pog to your 
                 fonts folder.
-  -u pog        Uninstall the fonts in this pog.
-  -l            List the names of all the pogs.
-  -s num        Set a new default point size.
-  -v num        Set a new default for how many fonts 
+  -u pog --uninstall=pog
+                Uninstall the fonts in this pog.
+  -l --list     List the names of all the pogs.
+  -s num --size=num
+                Set a new default point size.
+  -n num --number=num
+                Set a new default for how many fonts 
                 to view at one go. Don't overdo this.
-  -t "text"     Set a new default sample text.  
+  -t "text" --text="text"
+                Set a new default sample text.  
                 "This is an ex-parrot!", say. 
                 Be sure to use the quotes.
-  -p pog        Purge the pog of ttf files that are no
-                longer really there.""")
+  -p pog --purge=pog
+                Purge the pog of ttf files that are no
+                longer really there.
+  -c folder --check=folder
+                Check for bad fonts that crash Fonty.
+                It will recurse through sub-folders.
+                This will build a file:
+                ~/.fontypython/segfonts
+                After using this tool you should be
+                able to browse folders that crashed
+                Fonty. (The reason it's not done
+                by default is that it's very slow.)
+                * NOTE: The fonts that crash Fonty
+                are probably still perfectly good
+                and can be used in other apps. It's
+                simply a bug in the library we use to
+                access fonts that chokes things. This
+                will (hopefully) improve in the future.
+                """)
 
 
 use = _("""%(c)s [OPTIONS] [VIEW] [TARGET]
@@ -62,7 +86,7 @@ then "quote the name."
 
 Please use -e to see more info.
 
-NEWS : We now support TTF, OTF, Type1 (PFB, PFM) 
+NEWS : We now support TTF, OTF, Type1 (PFB, PFA) 
 and TTC fonts.
 
 %(version)s
@@ -120,7 +144,7 @@ Tips:
   the app. Sometimes the system needs a while to
   reflect the new fonts in your fonts folder.
 
-Examples: - mostly using short options, see -h
+Examples: - all using short options, see -h
 =========
 %(c)s /path/to/fonts/ttfs/a
   This will start off showing the fonts in that path.
@@ -170,7 +194,13 @@ Examples: - mostly using short options, see -h
   really on your drive/media anymore (perhaps you
   deleted them or the cat did) then this will go 
   through your pog and cull them.
-    
+
+%(c)s -c /some/path/to/fonts
+  If Fonty keeps crashing on /some/path/to/fonts
+  then you should run a check on that folder.
+  This will 'mark' the dangerous fonts and let
+  you use that folder in the future.
+
 Your fontypython folder is:
 %(folder)s
 If you want to backup your pogs, that's where ya go.
@@ -181,7 +211,7 @@ If you want to backup your pogs, that's where ya go.
 ## These two are used in setup.py
 description = _("Fonty Python - view and manage all kinds of fonts on Gnu/Linux")
 long_description = _("""Manage your fonts on Gnu/Linux.
-NEWS : We now support TTF, OTF, Type1 (PFB, PFM) 
+NEWS : We now support TTF, OTF, Type1 (PFB, PFA) 
 and TTC fonts.
 
 Many designers have collections of font files in big
@@ -270,6 +300,19 @@ You can also get the latest version from here:
 http://www.pythonware.com/products/pil/index.htm
 """)
 
+## Won't xlate the thanks:
+thanks = u"""Many thanks to:
+Robin Dunn - wxPython and much sundry help.
+Martin v. Löwis - Essential concepts regarding unicode and files.
+Pietro Battiston - Italian translation.
+Baptiste - French translation and many ideas.
+Jason Yamada-Hanff - For the wiki, at least :)
+Kartik Mistry - For man pages, Debian packages and patience.
+
+savannah.nongnu.org - For the hosting.
+
+And all those I have neglected to include.
+"""
 GPL = """
                     GNU GENERAL PUBLIC LICENSE
                        Version 3, 29 June 2007
