@@ -154,7 +154,8 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
         pilList=[]
         totheight = 0
         maxwidth = [self.width] # to figure-out the biggest width
-        for pilimage,height,pilwidth in self.fitem.generatePilFont( self.width, self.maxHeight ):
+
+        for pilimage,height,pilwidth in self.fitem.generatePilFont( self.maxHeight ):#( self.width, self.maxHeight ):
             pilList.append( [pilimage, height, pilwidth] )
             totheight += height + spacer
             maxwidth.append(pilwidth)
@@ -250,43 +251,86 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
                     wxfaceimage.SetData( pilimage.convert('RGB').tostring() ) 
                     faceBitmap = wxfaceimage.ConvertToBitmap() 
                 except:
-                    ps.pub( show_error_and_abort,\
-                    _("Error creating a wximage of %s") % self.fitem.glyphpaf_unicode)
-                    
-                ## Place it into the main image, down a tad so it looks better.
-                facex = 10
-                if i > 0: facex = 24 # Shift sub-faces over a little
-                memDc.DrawBitmap( faceBitmap, facex, y + 2, True )
-               
-                ## draw the fading effect under the faceBitmap  
-                ## only if we are at the end of the faces
-                ## must be done here so text goes above it.
-                if i == self.fitem.numFaces-1:
-                    self.__fadeEffect( memDc, totheight, maxwidth, (218,218,218) )
-                
-                ## Now draw the text showing the font name/family/style.
-                ## -- suggested by Chris Mohler.
-                ## Prep the text to show "font family name (font file name)"
-                ## Added Style info 3 Dec 2006:
-                if self.fitem.inactive: fcol = "gray"
-                else: fcol = "black"
-                
-                ## Postion 
-                texty = y + glyphHeight + (spacer/8)
+                    ## Hey, whaddayaknow, this happened! The font is called 
+                    ## 50SDINGS.ttf and it screws the pooch.
+                    ## What happened was that it returned width = 0
+                    ## which then can't be drawn. So I forced it to 1.
+                    ## Thus, that error is 'fixed', so this is back to being
+                    ## unknown.
+                    ## I am going to create a generic badfont.
 
-                txt = "%s - %s - [%s]" % (self.fitem.family[i], self.fitem.style[i], self.name)
-                self.__fatFont(memDc, 16, texty, fcol, "white", 10, wx.NORMAL, txt)
-                
-                ## Special message
-                if self.fitem.inactive:
-                    self.__fatFont\
-                    (memDc, 16, texty + 14, "black", "white", 10, wx.NORMAL, self.fitem.msg)
+                    block = (255,255,0)
+                    fadecol = (200,200,0)
+                    fcol = "red"
+                    bcol = fadecol 
+                        
+                    wxMainBitmap = wx.EmptyImage( self.width, self.minHeight ).ConvertToBitmap()
+                    ## White it out
+                    memDc = wx.MemoryDC()
+                    memDc.SelectObject( wxMainBitmap )
+                    memDc.SetBackground(wx.Brush( block, wx.SOLID)) 
+                    memDc.Clear()
+                    ## Fade effect
+                    self.__fadeEffect( memDc, self.minHeight, self.width, fadecol )
+
+                    ## Message
+                    texty = 3
+                    self.__fatFont(memDc, 12, texty, fcol, bcol, 10, wx.NORMAL, _("This font cannot be drawn") )
+                    ## Path
+                    texty = 20
+                    self.__fatFont(memDc, 12, texty, fcol, bcol, 7, wx.NORMAL, self.fitem.glyphpaf_unicode)
+                    ## Filename
+                    texty = 34
+                    self.__fatFont(memDc, 10, texty, fcol, bcol, 10, wx.NORMAL, "Name: %s" % self.name)
                     
-                ## Move TOP down to next BOTTOM (for next sub-face)
-                y = y + glyphHeight +  spacer
-                
-                ## Goto next face, if any.
-                i += 1            
+                    ## Special message - it may already be in a Pog.
+                    if self.fitem.inactive:
+                        self.__fatFont\
+                        (memDc, 10, texty + 15, "black", bcol, 10, wx.NORMAL, self.fitem.msg)
+
+                    ## Record the calculated height
+                    self.height = self.minHeight
+
+
+                    #ps.pub( show_error_and_abort,\ # no longer aborting.
+                    print _("Error creating a wximage of %s") % [self.fitem.glyphpaf_unicode] # list hack, cos I'm still nervous about unicode errors.
+                ## do this if there was no error:
+                else:
+                    
+                    ## Place it into the main image, down a tad so it looks better.
+                    facex = 10
+                    if i > 0: facex = 24 # Shift sub-faces over a little
+                    memDc.DrawBitmap( faceBitmap, facex, y + 2, True )
+                   
+                    ## draw the fading effect under the faceBitmap  
+                    ## only if we are at the end of the faces
+                    ## must be done here so text goes above it.
+                    if i == self.fitem.numFaces-1:
+                        self.__fadeEffect( memDc, totheight, maxwidth, (218,218,218) )
+                    
+                    ## Now draw the text showing the font name/family/style.
+                    ## -- suggested by Chris Mohler.
+                    ## Prep the text to show "font family name (font file name)"
+                    ## Added Style info 3 Dec 2006:
+                    if self.fitem.inactive: fcol = "gray"
+                    else: fcol = "black"
+                    
+                    ## Postion 
+                    texty = y + glyphHeight + (spacer/8)
+
+                    txt = "%s - %s - [%s]" % (self.fitem.family[i], self.fitem.style[i], self.name)
+                    self.__fatFont(memDc, 16, texty, fcol, "white", 10, wx.NORMAL, txt)
+                    
+                    ## Special message
+                    if self.fitem.inactive:
+                        self.__fatFont\
+                        (memDc, 16, texty + 14, "black", "white", 10, wx.NORMAL, self.fitem.msg)
+                        
+                    ## Move TOP down to next BOTTOM (for next sub-face)
+                    y = y + glyphHeight +  spacer
+                    
+                    ## Goto next face, if any.
+                    i += 1            
         
             ## Record the calculated height
             self.height = totheight
@@ -303,7 +347,13 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
         memDc.DrawLine( 0, self.height-1, maxwidth, self.height-1 )
 
         self.bitmap = wxMainBitmap
-        
+
+
+
+##    def __drawBadFont( self, block, fadecol, fcol, bcol ):
+##        """Factored out on 22 Jan 2008 because badfonts suddenly happen in more than one place. """
+
+
     def __fadeEffect( self, memDc, liney, width, col ):
         """
         Baptiste's idea!
